@@ -298,13 +298,31 @@ def create(
         exists=True,
         readable=True,
         help='Path of the Analytic description (YAML file)'),
-    company: str = typer.Option(default=None, help='Company identifier'),
+        company: str = typer.Option(default=None, help='Company identifier'),
 ):
     """ Create a new analytic """
     analytic_desc = parse_analytic_yaml(description)
     analytic = Analytic.from_yaml(analytic_desc)
     typer.secho('✓ Analytic description is valid', fg=typer.colors.GREEN)
+
     sdk = alteia_sdk()
+
+    if analytic.name and not company:
+        company_shortname = analytic.name.split('/')[0]
+        companies = sdk._providers['auth_api'].post(
+            '/search-companies', {
+                'filter': {'short_name': {'$eq': company_shortname}},
+                'limit': 1
+            })
+        if companies['total'] != 1:
+            typer.secho(
+                f'✖ Impossible to find company with shortname {company_shortname}:',
+                fg=typer.colors.RED
+            )
+            raise typer.Exit(1)
+
+        company = companies['results'][0]['_id']
+
     found_analytics = sdk.analytics.search(name=analytic.name)
     if found_analytics:
         typer.secho(
